@@ -21,6 +21,7 @@ class Teradata(Dialect):
             "^=": TokenType.NEQ,
             "NE": TokenType.NEQ,
             "NOT=": TokenType.NEQ,
+            "ST_GEOMETRY": TokenType.GEOMETRY,
         }
 
         # teradata does not support % for modulus
@@ -105,6 +106,11 @@ class Teradata(Dialect):
             )
 
     class Generator(generator.Generator):
+        TYPE_MAPPING = {
+            **generator.Generator.TYPE_MAPPING,  # type: ignore
+            exp.DataType.Type.GEOMETRY: "ST_GEOMETRY",
+        }
+
         PROPERTIES_LOCATION = {
             **generator.Generator.PROPERTIES_LOCATION,  # type: ignore
             exp.PartitionedByProperty: exp.Properties.Location.POST_INDEX,
@@ -125,3 +131,8 @@ class Teradata(Dialect):
 
         def mod_sql(self, expression: exp.Mod) -> str:
             return self.binary(expression, "MOD")
+
+        def datatype_sql(self, expression: exp.DataType) -> str:
+            type_sql = super().datatype_sql(expression)
+            prefix_sql = expression.args.get("prefix")
+            return f"SYSUDTLIB.{type_sql}" if prefix_sql else type_sql
